aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java')
-rw-r--r--src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java b/src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java
index ded83ff..5cc4954 100644
--- a/src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java
+++ b/src/main/java/at/gv/egiz/moazs/client/TnvzHelper.java
@@ -53,27 +53,27 @@ public class TnvzHelper {
/**
* Performs all tasks related to making a request to the tnvz service:
* Derives a tnvz:QueryPersonRequest from the {@code mzsRequest}, sends the QueryPersonRequest to
* {@code tvnzPort}, validates the tnvz's response and extracts the {@code Identification} Element.
* @param mzsRequest Data source for the QueryPersonRequest
* @param tvnzPort Client for communicating with the tnvz service
* @throws MoaZSException in case of an error.
* @return
*/
public IdentificationType performQueryPersonRequest(DeliveryRequestType mzsRequest,
- TNVZServicePort tvnzPort) {
+ TNVZServicePort tnvzPort) {
log.info("Perform Query Person Request for mzs:DeliveryRequest with AppDeliveryID={}",
mzsRequest.getMetaData().getAppDeliveryID());
- var tvnzQuery = buildQuery(mzsRequest);
- var tvnzResponse = tvnzPort.queryPerson(tvnzQuery);
- verifyResponse(tvnzResponse);
+ var tnvzQuery = buildQuery(mzsRequest);
+ var tnvzResponse = tnvzPort.queryPerson(tnvzQuery);
+ verifyResponse(tnvzResponse);
- var tvnzResult = getResult(tvnzResponse);
+ var tnvzResult = getResult(tnvzResponse);
var typesInRequest = extractListOfMimemtypesIn(mzsRequest);
- checkMimetypes(tvnzResult, typesInRequest);
+ checkMimetypes(tnvzResult, typesInRequest);
- return tvnzResult.getSuccess().getIdentification();
+ return tnvzResult.getSuccess().getIdentification();
}
private QueryPersonRequest buildQuery(DeliveryRequestType mzsRequest) {
@@ -173,14 +173,14 @@ public class TnvzHelper {
.collect(toSet());
}
- private void verifyResponse(QueryPersonResponse tvnzResponse) {
+ private void verifyResponse(QueryPersonResponse tnvzResponse) {
- var error = tvnzResponse.getError();
+ var error = tnvzResponse.getError();
if (error != null) {
throw MoaZSException.moaZSException(error.getText(), error.getCode());
}
- var results = tvnzResponse.getQueryResultList().getQueryResult();
+ var results = tnvzResponse.getQueryResultList().getQueryResult();
if (results.isEmpty()) {
throw MoaZSException.moaZSException(MZS_NO_TNVZ_PERSON_QUERY_RESULTS_ERROR_MSG,
MoaZSException.ERROR_MZS_NO_TNVZ_PERSON_QUERY_RESULTS);
@@ -196,8 +196,8 @@ public class TnvzHelper {
}
}
- private PersonResultType getResult(QueryPersonResponse tvnzResponse) {
- return tvnzResponse.getQueryResultList().getQueryResult().get(0);
+ private PersonResultType getResult(QueryPersonResponse tnvzResponse) {
+ return tnvzResponse.getQueryResultList().getQueryResult().get(0);
}
private void checkMimetypes(PersonResultType tnvzResult, Set<String> typesInRequest) {
@@ -53,27 +53,27 @@ public class TnvzHelper {
* Performs all tasks related to making a request to the tnvz service:
* Derives a tnvz:QueryPersonRequest from the {@code mzsRequest}, sends the QueryPersonRequest to
- * {@code tvnzPort}, validates the tnvz's response and extracts the {@code Identification} Element.
+ * {@code tnvzPort}, validates the tnvz's response and extracts the {@code Identification} Element.
* @param mzsRequest Data source for the QueryPersonRequest
@@ -53,27 +53,27 @@ public class TnvzHelper {
* @param mzsRequest Data source for the QueryPersonRequest
- * @param tvnzPort Client for communicating with the tnvz service
+ * @param tnvzPort Client for communicating with the tnvz service
* @throws MoaZSException in case of an error.
* @return